@@ -22,6 +22,9 @@ Main program of ibus-typing-booster
 '''
 from typing import Any
 from typing import Union
+from typing import Type
+from typing import Optional
+import types
 import os
 import sys
 import argparse
@@ -30,13 +33,13 @@ import logging
 import logging.handlers
 from signal import signal, SIGTERM, SIGINT
 # pylint: disable=wrong-import-position
-from gi import require_version # type: ignore
+from gi import require_version
 require_version('IBus', '1.0')
-from gi.repository import IBus # type: ignore
+from gi.repository import IBus
 require_version('Gio', '2.0')
-from gi.repository import Gio
+from gi.repository import Gio # type: ignore
 require_version('GLib', '2.0')
-from gi.repository import GLib
+from gi.repository import GLib # type: ignore
 # pylint: enable=wrong-import-position
 
 import itb_util
@@ -44,6 +47,22 @@ import itb_version
 
 LOGGER = logging.getLogger('ibus-typing-booster')
 
+def log_unhandled_exception(
+    exc_type: Type[BaseException],
+    exc_value: BaseException,
+    exc_traceback: Optional[types.TracebackType]
+) -> None:
+    '''Log any unhandled exception.'''
+    if issubclass(exc_type, KeyboardInterrupt):
+        sys.__excepthook__(exc_type, exc_value, exc_traceback)
+        return
+    LOGGER.error(
+        'Unhandled exception',
+        exc_info=(exc_type, exc_value, exc_traceback)
+    )
+
+sys.excepthook = log_unhandled_exception
+
 DEBUG_LEVEL = int(0)
 try:
     DEBUG_LEVEL = int(str(os.getenv('IBUS_TYPING_BOOSTER_DEBUG_LEVEL')))
@@ -362,12 +381,11 @@ def write_xml() -> None:
         description = 'A completion input method to speedup typing.'
         symbol = '🚀'
         if (itb_util.is_desktop('gnome')
-            and itb_util.get_gnome_shell_version() >= (49, 0, 0)):
+            and itb_util.get_gnome_shell_version() >= (48, 3)):
             # If running on Gnome and gnome-shell is new enough to contain
             # https://gitlab.gnome.org/GNOME/gnome-shell/-/merge_requests/3753
             # make the symbol black and white:
             symbol = '🚀\uFE0E'
-        setup = SETUP_TOOL
         icon_prop_key = 'InputMode'
         rank = 0
         schema_path = '/org/freedesktop/ibus/engine/typing-booster/'
@@ -401,7 +419,7 @@ def write_xml() -> None:
             language = m17n_lang
             icon =  m17n_db_info.get_icon(ime)
             description = m17n_db_info.get_description(ime)
-            setup = SETUP_TOOL + f' --engine-name {name}'
+        setup = SETUP_TOOL + f' --engine-name {name}'
         gsettings = Gio.Settings(
             schema='org.freedesktop.ibus.engine.typing-booster',
             path=schema_path)
@@ -481,7 +499,6 @@ def main() -> None:
     LOGGER.addHandler(log_handler)
     LOGGER.info('********** STARTING **********')
 
-    IBus.init()
     if _ARGS.daemon:
         if os.fork():
             sys.exit()
